slepc-3.18.0 2022-10-01
Report Typos and Errors

## Basis Vectors - BV

The BV package provides the concept of a block of vectors that represent the basis of a subspace. It is a convenient way of handling a collection of vectors that often operate together, rather than working with an array of Vec.

These routines are usually not needed by application programmers.

test1.c
test10.c
test11.c
test12.c
test13.c
test14.c
test15.c
test16.c
test17.c
test18.c
test1f.F90
test2.c
test3.c
test4.c
test5.c
test6.c
test7.c
test8.c
test9.c
makefile